<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
  <!-- 
        Feuille de Style pour l'affichage détaillée d'une gare
       
        auteur : Matthias Colin
        version : 1.0 (14/05/2010)
  -->

  <!-- paramètre nomGare : nom de la gare à détailler
       on vérifiera que cette gare est bien sur la ligne de train considérée
  -->
  <xsl:param name="nomGare" />

  <xsl:output method="html" encoding="utf-8" />

  <!-- main template -->
  <xsl:template match="Ligne">
    <html>
      <head>
        <title>Gare de <xsl:value-of select="$nomGare" /> sur la ligne de train :
               <xsl:value-of select="@nom" /></title>
      </head>
      <body>
        <h1>Gare de <xsl:value-of select="$nomGare" /> sur la ligne de train : 
             <xsl:value-of select="@nom" /></h1>
        <xsl:choose>
           <xsl:when test="ListeGares/(GareTerminus|Gare)/@nom = $nomGare">
             <!-- un train sera affiché autant de fois qu'il s'arrête dans la gare recherchée
                  (normalement 1 fois) -->
             <h2>Arrivées</h2>
             <ul>
		     <xsl:for-each select="//Train/(Destination|Arret)[@gare = $nomGare]">
               <li>train <xsl:value-of select="../@num"/> en provenance de 
                 <xsl:value-of select="../Depart/@gare"/>,
                 arrivée à 
     			<!-- 1 seul des 2 attributs suivants existe -->
     			<xsl:value-of select="@heure"/>
     			<xsl:value-of select="@arrivee"/>
               </li>
             </xsl:for-each>
             </ul>

             <h2>Départs</h2>
             <ul>
     		<xsl:for-each select="//Train/(Depart|Arret)[@gare = $nomGare]">
               <li>train <xsl:value-of select="../@num"/> à destination de 
                 <xsl:value-of select="../Destination/@gare"/>,
                 départ à 
     			<!-- 1 seul des 2 attributs suivants existe -->
     			<xsl:value-of select="@heure"/>
     			<xsl:value-of select="@depart"/>
               </li>
             </xsl:for-each>
             </ul>
          </xsl:when>
          <xsl:otherwise>Gare non desservie sur cette ligne !
          </xsl:otherwise>
        </xsl:choose>
      </body>
    </html>
  </xsl:template>

</xsl:stylesheet>

<!-- quelques exemples d'utilisations :
java -jar saxon9he.jar trains.xml train2.xsl nomGare=Pau
java -jar saxon9he.jar trains.xml train2.xsl nomGare=Paris
java -jar saxon9he.jar trains.xml train2.xsl nomGare=Châtellerault
java -jar saxon9he.jar trains.xml train2.xsl nomGare='Saint Piere des Corps'
-->
